<?php

namespace Drupal\phonenumber_validation\Plugin\Validation\Constraint;

use Drupal\Core\Config\Entity\ThirdPartySettingsInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\phonenumber_validation\PhoneValidator;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;

/**
 * Validates the PhoneConstraint constraint.
 */
class PhoneConstraintValidator extends ConstraintValidator implements ContainerInjectionInterface {

  /**
   * Phone number validator service.
   *
   * @var \Drupal\phonenumber_validation\PhoneValidator
   */
  protected $PhoneValidator;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('phonenumber_validation.validator'));
  }

  /**
   * Constructs a new PhoneConstraintValidator.
   *
   * @param \Drupal\phonenumber_validation\PhoneValidator $Phone_validator
   *   Phone number validation service.
   */
  public function __construct(PhoneValidator $Phone_validator) {
    $this->PhoneValidator = $Phone_validator;
  }

  /**
   * {@inheritdoc}
   */
  public function validate($value, Constraint $constraint) {
    try {
      $number = $value->getValue();
    }
    catch (\InvalidArgumentException $e) {
      return;
    }
    /** @var \Drupal\field\Entity\FieldConfig $field */
    $field = $value->getFieldDefinition();

    // Check field allows storing a third party settings.
    if (!$field instanceof ThirdPartySettingsInterface) {
      return;
    }

    $settings = $field->getThirdPartySettings('phonenumber_validation');
    // If no settings found we must skip validation.
    if (empty($settings)) {
      return;
    }
    // Validate number against validation settings.
    if (!$this->validator->isValid(
      $number['value'],
      $field->getThirdPartySetting('phonenumber_validation', 'format'),
      $field->getThirdPartySetting('phonenumber_validation', 'country')
    )) {
      $this->context->addViolation($constraint->message, ['@number' => $number['value']]);
    }
  }

}
