<?php

namespace Drupal\phonenumber\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'phone_country' formatter.
 *
 * @FieldFormatter(
 *   id = "phone_country",
 *   label = @Translation("Country"),
 *   field_types = {
 *     "phone"
 *   }
 * )
 */
class PhoneCountryFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return parent::defaultSettings() + ['type' => 'name'];
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $settings = $this->getSettings() + static::defaultSettings();

    $form['type'] = [
      '#type' => 'radios',
      '#options' => [
        'name' => $this->t('Country name'),
        'code' => $this->t('Country code'),
      ],
      '#default_value' => $settings['type'],
    ];

    return parent::settingsForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];
    $settings = $this->getSettings() + static::defaultSettings();

    //if (!empty($settings['type'])) {
      $texts = [
        'name' => $this->t('Show as country name'),
        'code' => $this->t('Show as country code'),
        'iso2' => $this->t('Show as country iso2'),
      ];
      $summary[] = $texts[$settings['type']];
    //}

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $element = [];
    $settings = $this->getSettings() + static::defaultSettings();

    foreach ($items as $delta => $item) {
      if (!$item->getValue()['country_code'] || !$item->getValue()['country_iso2']) {
        continue;
      }
      /** @var \Drupal\Core\Locale\CountryManagerInterface $country_manager */
      $country_manager = \Drupal::service('country_manager');
      $countries = $country_manager->getList();

      if ($settings['type'] == 'code') {
        $element[$delta] = [
          '#plain_text' => $item->getValue()['country_code'],
        ];
      }
      elseif ($settings['type'] == 'name') {
        $element[$delta] = [
          '#plain_text' => $countries[$item->getValue()['country_iso2']],
        ];
      }
      else {
        $element[$delta] = [
          '#plain_text' => $item->getValue()['country_iso2'],
        ];
      }
    }

    return $element;
  }

}
